@@ -38,7 +38,7 @@ static DirtyCallbackFunc parent_dirty_cb;
 /* table widget callback prototypes */
 static void remove_cb (GtkWidget *widget);
 static void selection_changed (GtkTreeSelection *selection);
-static void dirty_cb (GtkWidget *widget);
+static void session_properties_dirty_cb (GtkWidget *widget);
 
 static GtkWidget*
 create_table (void)
@@ -48,8 +48,8 @@ create_table (void)
   remove_button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
   gsm_atk_set_description (remove_button, _("Remove the currently selected client from the session."));
   gtk_widget_set_sensitive (GTK_WIDGET (remove_button), FALSE);
-  gtk_signal_connect(GTK_OBJECT (remove_button), "clicked",
-		     GTK_SIGNAL_FUNC (remove_cb), NULL);
+  g_signal_connect(remove_button, "clicked",
+		   G_CALLBACK (remove_cb), NULL);
 
   apply_button = gtk_button_new_from_stock (GTK_STOCK_APPLY);
   gsm_atk_set_description (apply_button, _("Apply changes to the current session"));
@@ -63,8 +63,8 @@ create_table (void)
   g_signal_connect(gtk_tree_view_get_selection (GTK_TREE_VIEW (client_list)),
 		   "changed", G_CALLBACK (selection_changed),
 		   client_list);
-  gtk_signal_connect(GTK_OBJECT(client_list), "dirty",
-		     GTK_SIGNAL_FUNC (dirty_cb), NULL);
+  g_signal_connect(client_list, "dirty",
+		     G_CALLBACK (session_properties_dirty_cb), NULL);
 
   client_editor = gsm_client_list_get_editor (GSM_CLIENT_LIST (client_list));
 
@@ -98,13 +98,6 @@ create_table (void)
   return vbox;
 }
 
-static gboolean init_settings = FALSE;
-
-static const struct poptOption options[] = {
-  {"init-session-settings", '\0', POPT_ARG_NONE, &init_settings, 0, N_("Initialize session settings"), NULL},
-  {NULL, '\0', 0, NULL, 0}
-};
-
 GtkWidget *
 session_properties_create_page (DirtyCallbackFunc dcf)
 {
@@ -145,7 +138,7 @@ selection_changed (GtkTreeSelection *selection)
 
 /* This is called when an change is made in the client list.  */
 static void
-dirty_cb (GtkWidget *widget)
+session_properties_dirty_cb (GtkWidget *widget)
 {
   parent_dirty_cb ();
 }
